==> lib-gwt-file-0.3.3.jar: org/vectomatic/file/events/LoadEndEvent.java <==
/**********************************************
 * Copyright (C) 2011 Lukas laag
 * This file is part of lib-gwt-file.
 * 
 * lib-gwt-file is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * lib-gwt-file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with lib-gwt-file.  If not, see http://www.gnu.org/licenses/
 **********************************************/
package org.vectomatic.file.events;

import com.google.gwt.event.dom.client.DomEvent;

/**
 * The loadstart event is triggered when the read request has completed (either in success or failure).
 */
public class LoadEndEvent extends ProgressEventBase<LoadEndHandler> {
	private static final Type<LoadEndHandler> TYPE = new Type<LoadEndHandler>(
			"loadend", new LoadEndEvent());

	/**
	 * Protected constructor, use
	 * {@link DomEvent#fireNativeEvent(com.google.gwt.dom.client.NativeEvent, com.google.gwt.event.shared.HasHandlers)}
	 * to fire mouse out events.
	 */
	protected LoadEndEvent() {
	}

	/**
	 * @return the handler type
	 */
	public Type<LoadEndHandler> getAssociatedType() {
		return TYPE;
	}

	/**
	 * @return the handler type
	 */
	public static Type<LoadEndHandler> getType() {
		return TYPE;
	}

	@Override
	protected void dispatch(LoadEndHandler handler) {
		handler.onLoadEnd(this);
	}
}

==> lib-gwt-file-0.3.7.jar: org/vectomatic/file/events/LoadEndEvent.java <==
/**********************************************
 * Copyright (C) 2011 Lukas laag
 * This file is part of lib-gwt-file.
 * 
 * lib-gwt-file is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * lib-gwt-file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with lib-gwt-file.  If not, see http://www.gnu.org/licenses/
 **********************************************/
package org.vectomatic.file.events;

import com.google.gwt.event.dom.client.DomEvent;

/**
 * The loadend event is triggered when the read request has completed (either in success or failure).
 */
public class LoadEndEvent extends ProgressEventBase<LoadEndHandler> {
	private static final Type<LoadEndHandler> TYPE = new Type<LoadEndHandler>(
			"loadend", new LoadEndEvent());

	/**
	 * Protected constructor, use
	 * {@link DomEvent#fireNativeEvent(com.google.gwt.dom.client.NativeEvent, com.google.gwt.event.shared.HasHandlers)}
	 * to fire mouse out events.
	 */
	protected LoadEndEvent() {
	}

	/**
	 * @return the handler type
	 */
	public Type<LoadEndHandler> getAssociatedType() {
		return TYPE;
	}

	/**
	 * @return the handler type
	 */
	public static Type<LoadEndHandler> getType() {
		return TYPE;
	}

	@Override
	protected void dispatch(LoadEndHandler handler) {
		handler.onLoadEnd(this);
	}
}
